#pyareas
##A simple Python library for finding the areas of 2D shapes

##Shapes Included:

Square,
Triangle,
Rectangle,
Circle,
Parellelogram,
Ellipse,
Rhombus,
Trapezoid,
Polygon(regular)

##Install command:
```
pip install pyareas
```

##Example:
```
from pyareas import *

mysquarearea = Square(10)

print(mysquarearea):
```
Gives the output:
```
100
```
